=======
History
=======

0.1.2 (2019-10-25)
------------------
In organism_load_plan.json, changed types of edge columns
"Experimental System Type" and "Throughput" to be "list_of_string",
and "Score" to be "list_of_double".
This change resolves UD-761 Biogrid network can't be imported to Cytoscape.

0.1.1 (2019-08-23)
------------------
* First release on PyPI.
